# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-04-06 00:55
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='Nome')),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('tel_prefix', models.IntegerField(verbose_name='DDD')),
                ('tel', models.IntegerField(verbose_name='Telefone')),
                ('tel_sufix', models.IntegerField(blank=True, null=True, verbose_name='Ramal')),
                ('company', models.CharField(blank=True, max_length=100, null=True, verbose_name='Empresa')),
                ('postal', models.IntegerField(verbose_name='CEP')),
                ('state', models.CharField(max_length=200, verbose_name='Estado')),
                ('city', models.CharField(max_length=200, verbose_name='Cidade')),
                ('district', models.CharField(max_length=200, verbose_name='Bairro')),
                ('address', models.CharField(max_length=200, verbose_name='Endereço')),
                ('address_number', models.IntegerField(blank=True, null=True, verbose_name='Número')),
                ('address_complement', models.CharField(blank=True, max_length=200, null=True, verbose_name='Complemento')),
                ('message', models.TextField(verbose_name='Mensagem')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Enviado em')),
                ('device', models.CharField(blank=True, max_length=100, null=True, verbose_name='Dispositivo')),
            ],
            options={
                'verbose_name_plural': 'Contatos',
                'verbose_name': 'Contato',
            },
        ),
        migrations.CreateModel(
            name='Profession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name_plural': 'Áreas de atuação',
                'verbose_name': 'Área de atuação',
            },
        ),
        migrations.CreateModel(
            name='Subject',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name_plural': 'Assuntos',
                'verbose_name': 'Assunto',
            },
        ),
        migrations.DeleteModel(
            name='Press',
        ),
        migrations.DeleteModel(
            name='Video',
        ),
        migrations.AddField(
            model_name='contact',
            name='profession',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contacts', to='contact.Profession', verbose_name='Área de atuação'),
        ),
        migrations.AddField(
            model_name='contact',
            name='subject',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='contacts', to='contact.Subject', verbose_name='Assunto'),
        ),
    ]
