# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2018-10-16 14:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0002_auto_20160405_2155'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Ativo?'),
        ),
    ]
