# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-01-05 16:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0006_auto_20191008_1416'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='order',
            field=models.IntegerField(null=True, verbose_name='Ordem'),
        ),
    ]
