# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-01-05 16:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0007_subject_order'),
    ]

    operations = [
        migrations.AlterField(
            model_name='subject',
            name='order',
            field=models.IntegerField(default=0, null=True, verbose_name='Ordem'),
        ),
    ]
