# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2019-09-06 13:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0004_auto_20190814_1713'),
    ]

    operations = [
        migrations.AddField(
            model_name='contact',
            name='its_budget',
            field=models.BooleanField(default=False, verbose_name='É um orçamento?'),
        ),
    ]
