# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2019-10-08 17:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0005_contact_its_budget'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contact',
            name='tel',
            field=models.CharField(max_length=11, verbose_name='Telefone'),
        ),
    ]
