# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2019-08-14 20:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0003_subject_is_active'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contact',
            name='address',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Endereço'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='city',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Cidade'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='district',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Bairro'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='postal',
            field=models.IntegerField(blank=True, null=True, verbose_name='CEP'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='state',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Estado'),
        ),
    ]
