# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-04-06 00:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Press',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Título')),
                ('desc', models.TextField(verbose_name='Descrição')),
                ('image', models.ImageField(upload_to='/vagrant/application/uploads/clipping', verbose_name='Imagem')),
                ('order', models.IntegerField(null=True, unique=True, verbose_name='Ordem')),
            ],
            options={
                'ordering': ('order',),
                'verbose_name': 'Matéria',
                'verbose_name_plural': 'Matérias',
            },
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Título')),
                ('desc', models.TextField(verbose_name='Descrição')),
                ('video', models.URLField(unique=True, verbose_name='URL do Youtube')),
                ('order', models.IntegerField(null=True, unique=True, verbose_name='Ordem')),
            ],
            options={
                'ordering': ('order',),
                'verbose_name': 'Vídeo',
                'verbose_name_plural': 'Vídeos',
            },
        ),
    ]
